==> maDB_1.4.0.tar.gz: maDB/man/getAnnotation.Rd <==
\name{getAnnotation}
\alias{getAnnotation}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Annotate a gene}
\description{
This function tries to retrieve the annotation for a gene (or a list of genes) to different public repository IDs.
}
\usage{
getAnnotation(id = NULL, con = NULL, method = "local", chip = NULL, v = TRUE, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{id}{The gene ID (or IDs), for example Affymetrix probe set IDs, GenBank IDs...}
  \item{con}{The database connection to the \code{"maDB"} database, if method is \code{"db"}. If the annotation should be done using the ensembl mart database using the \pkg{biomaRt} package the mart connection object should be submitted with con. If local annotation (for example using Bioconductors Annotation packages) should be used this atribute can be omitted.}
  \item{method}{The annotation method, one of \code{c("local","db","mart")}.}
  \item{chip}{An identifier for the chip or package that should be used to annotate the id. For the Affymetrix HG U133plus2 chip for example \code{"hgu133plus2"} should be submitted.}
  \item{v}{If additional output should be written to the console.}
  \item{\dots}{additional parameters.}
}
\value{
A matrix where the rows correspond to the ids (genes) and the columns the available annotations for the genes.
}
\author{Johannes Rainer}
\section{Warning}{The local annotation using annotation packages is not implemented yet!}
\seealso{\code{\link{dbGetAnnotation}}}
\keyword{data}

==> maDB_1.12.0.tar.gz: maDB/man/getAnnotation.Rd <==
\name{getAnnotation}
\alias{getAnnotation}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Annotate a gene}
\description{
This function retrieves annotation for a gene (or a list of genes) to different public repository IDs.
}
\usage{
getAnnotation(id = NULL, con = NULL, method = "local", chip = NULL, v = TRUE, ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{id}{The gene ID (or IDs), for example Affymetrix probe set IDs, GenBank IDs...}
  \item{con}{The database connection to the \code{"maDB"} database, if method is \code{"db"}. If the annotation should be done using the ensembl mart database using the \pkg{biomaRt} package the mart connection object should be submitted with con. If local annotation (for example using Bioconductors Annotation packages) should be used this atribute can be omitted.}
  \item{method}{The annotation method, one of \code{c("local","db","mart")}.}
  \item{chip}{An identifier for the chip or package that should be used to annotate the id. e.g. \code{"hgu133plus2"}  should be submitted for the Affymetrix HG-U133plus2 chip.}
  \item{v}{If additional output should be written to the console.}
  \item{\dots}{additional parameters.}
}
\value{
A matrix where the rows correspond to the ids (genes) and the columns to the available annotations for the genes.
}
\author{Johannes Rainer}
\section{Warning}{The local annotation using annotation packages is not implemented yet!}
\seealso{\code{\link{dbGetAnnotation}}}
\keyword{data}
